// vim: set tw=80 ts=2 sw=2 sts=2:
import { Component, Input, ViewChild } from '@angular/core';

import { NgbActiveModal } from '@ng-bootstrap/ng-bootstrap';

import { Account } from './account';
import { AccountFormComponent } from './accountForm.component';

@Component({
  selector: 'account-edit-modal',
  template: `
<div class="modal-header">
  <h3 class="modal-title" id="modal-title">{{ title() }}</h3>
</div>

<div class="modal-body" id="modal-body">
  <account-form [account]="account" (submit)="submit()" #accountForm="accountForm"></account-form>
</div>

<div class="modal-footer">
  <button class="btn btn-primary" [disabled]="!accountForm.form.valid" (click)="submit()">
    Save
  </button>

  <button class="btn btn-default" (click)="cancel()">
    Cancel
  </button>
</div>
  `
})
export class AccountEditModalComponent {
  @Input() account: Account;
  @ViewChild('accountForm') accountForm: AccountFormComponent;

  constructor(private activeModal: NgbActiveModal) {}

  title(): string {
    if(this.account.id) {
      return "Account #" + this.account.id;
    } else {
      return "New account";
    }
  }

  submit(): void {
    let formModel = this.accountForm.form.value;
    let account = new Account();

    account.id = this.account.id;
    account.name = formModel.name;
    account.authorized_overdraft = formModel.authorizedOverdraft;

    this.activeModal.close(account);
  }

  cancel(): void {
    this.activeModal.dismiss("closed");
  }
}
